@@ -1,6 +1,6 @@
 import cv2
 import uuid
-from fer import FER
+#from fer import FER
 
 
 
@@ -9,11 +9,13 @@ def get(image):
 
 def get_emotions(image):
 
+    '''
     emo_detector = FER()
     # Capture all the emotions on the image
     captured_emotions = emo_detector.detect_emotions(image)
     top_emotion = emo_detector.top_emotion(image)
 
     e, p = top_emotion
+    '''
 
-    return e
\ No newline at end of file
+    return None
\ No newline at end of file
